.. Typed Settings documentation master file, created by
   sphinx-quickstart on Tue Sep 29 22:40:43 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Typed Settings's documentation!
==========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   apiref



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
